@@ -1,7 +1,7 @@
-# earth.regress.R: earth.regress is used only for testing Regress in earth.c
-#                  (it is called using earth:::earth.regress in test.earth.full.R)
+# earth.regress.R: earth_regress is used only for testing Regress in earth.c
+#                  (it is called using earth:::earth_regress in test.earth.full.R)
 
-earth.regress <- function(
+earth_regress <- function(
     x         = stop("no 'x' argument"), # NAs are not allowed in x or y
     y         = stop("no 'y' argument"),
     weights   = NULL,               # case weights
@@ -11,7 +11,7 @@ earth.regress <- function(
     # expand factors, convert to double matrix with col names
     env <- parent.frame()
     x <- expand.arg(x, env, trace=0)
-    y <- expand.arg(y, env, trace=0, is.y.arg=TRUE, xname=trunc.deparse(substitute(y)))
+    y <- expand.arg(y, env, trace=0, is.y.arg=TRUE, name=trunc.deparse(substitute(y)))
     if(nrow(x) == 0)
         stop0("no 'x' values")
     if(ncol(x) == 0)    # this happens for example for earth(Volume~Volume,data=trees)
@@ -68,7 +68,8 @@ earth.regress <- function(
         as.integer(ncases),     # const int*   pnCases     in: number of rows in x and in y
         as.integer(nresp),      # const int*   pnResp      in: number of cols in y
         as.integer(ncols),      # int*         pnCols      in: number of columns in x
-        as.logical(used.cols),  # const bool   UsedCols[]) in: specifies used columns in x
+        as.logical(used.cols),  # const int    UsedColsR[]) in: specifies used columns in x
+                                #                               (assume R LOGICAL is stored as int)
         PACKAGE="earth")
 
     rval$fitted.values <- y - rval$residuals
